# GenerateSampleInspectionsRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**sample_inspection_rate** | **float** | See API specification Resource Guide &gt; Sampling API &gt; Sample inspections for more information | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

